
#rm(list = ls())

setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) #sets working directory to where this file is

library(haven)
library(lme4)
library(lmerTest)
library(psych)
library(mlogit)
library(aod)
library(multiwayvcov)
library(nnet)
library(psy)
library(mvtnorm)
library(MASS)
library(clusterSEs)
library(dplyr)
library(mnlogit)
library(texreg)
library(ggplot2)
library(tidyverse)
library(dfidx)


#start with cleaned data (data file name is different for replication files)

eu <- read_dta("eumisperceptions_clean.dta") 


#to be clear: country_id -->
  #1 = Germany
  #2 = Spain
  #3 = France
  #4 = Italy
  #5 = Poland
  #6 = Sweden

 
#create politized EU knowledge for DVS

eu1 <- mlogit.data(data=eu, shape="wide", choice="q20d_MEPdirect", reflevel="dk")
eu2 <- mlogit.data(data=eu, shape="wide", choice="q29d_powerEP", reflevel="dk")
eu3 <- mlogit.data(data=eu, shape="wide", choice="q29c_powerMS", reflevel="dk")


# other non-eu knowledge as DVs

eu_n1 <- mlogit.data(data=eu, shape="wide", choice="q20h_parl", reflevel="dk")
eu_n2 <- mlogit.data(data=eu, shape="wide", choice="q20i_headgov", reflevel="dk")
eu_n3 <- mlogit.data(data=eu, shape="wide", choice="q20j_largestparty", reflevel="dk")


#other EU not polarizing knowledge as DVs

eu4 <- mlogit.data(data=eu, shape="wide", choice="q20c_juncker", reflevel="dk")
eu5 <- mlogit.data(data=eu, shape="wide", choice="q20e_term", reflevel="dk")
eu6 <- mlogit.data(data=eu, shape="wide", choice="q20g_epelection", reflevel="dk")


############################################
# Main Outcomes: Polarizing EU knowledge
############################################


#main model

summary(mprobit_MEP_m1 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu    + female + qage   + bornabroad +  as.factor(country_id), 
                              data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m1 <- mlogit::mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                              data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m1 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                              data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with political party family control

summary(mprobit_MEP_m2 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu    + female + qage  + bornabroad +  as.factor(country_id)
                                 + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m2 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id)
                                + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m2 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id)
                                + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

#with pro-EU attitude control

summary(mprobit_MEP_m3 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + pro_eu   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m3 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + pro_eu    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m3 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + pro_eu   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with political ideology control

summary(mprobit_MEP_m4 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + conservatism   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m4 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + conservatism    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m4 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + conservatism   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#with pro-EU index control 

summary(mprobit_MEP_m5 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + proeu_attitudes   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m5 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + proeu_attitudes    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m5 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + proeu_attitudes   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#with subjective knowledge control

summary(mprobit_MEP_m6 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + self_conf_pre   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m6 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + self_conf_pre    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m6 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + self_conf_pre   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with CRT control 

summary(mprobit_MEP_m7 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + crt_sum   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m7 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + crt_sum    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m7 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + crt_sum   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#now with non-politicized pol nowledge as controls - have 3 different measurs

summary(mprobit_MEP_m8 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + noneuknowledge_sum   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m8 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + noneuknowledge_sum    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m8 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + noneuknowledge_sum   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


summary(mprobit_MEP_m9 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + nonpoleuknowledge_sum   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m9 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + nonpoleuknowledge_sum    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m9 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + nonpoleuknowledge_sum   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



summary(mprobit_MEP_m10 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu  + other_nonpoleuknowledge_sum   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m10 <- mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu   + other_nonpoleuknowledge_sum    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m10 <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu    + other_nonpoleuknowledge_sum   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



# finally, model where remove excl_natID and see if proxies get same results


summary(mprobit_MEP_m11 <- mlogit(q20d_MEPdirect ~ 1 | proimmigrants + polinterest + edu    + female + qage  + bornabroad +  as.factor(country_id), 
                                  data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m11 <- mlogit(q29d_powerEP ~ 1 |  proimmigrants + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m11 <- mlogit(q29c_powerMS ~ 1 |  proimmigrants + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                                 data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



summary(mprobit_MEP_m12 <- mlogit(q20d_MEPdirect ~ 1 | pro_eu + polinterest + edu    + female + qage  + bornabroad +  as.factor(country_id), 
                                  data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m12 <- mlogit(q29d_powerEP ~ 1 |  pro_eu + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m12 <- mlogit(q29c_powerMS ~ 1 |  pro_eu + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                                 data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )




summary(mprobit_MEP_m13 <- mlogit(q20d_MEPdirect ~ 1 | proeu_attitudes + polinterest + edu    + female + qage  + bornabroad +  as.factor(country_id), 
                                  data=eu1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m13 <- mlogit(q29d_powerEP ~ 1 |  proeu_attitudes + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m13 <- mlogit(q29c_powerMS ~ 1 |  proeu_attitudes + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                                 data=eu3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#by country 

for(i in 1:6){
 
eu_temp <- eu[eu$country_id==i,]   
assign(paste("eu_country", i, sep = ""), eu_temp)

eu1 <- mlogit.data(data=eu_temp, shape="wide", choice="q20d_MEPdirect", reflevel="dk")
assign(paste("eu1_country", i, sep = ""), eu1)
eu2 <- mlogit.data(data=eu_temp, shape="wide", choice="q29d_powerEP", reflevel="dk")
assign(paste("eu2_country", i, sep = ""), eu2)
eu3 <- mlogit.data(data=eu_temp, shape="wide", choice="q29c_powerMS", reflevel="dk")
assign(paste("eu3_country", i, sep = ""), eu3)
}



mprobit_MEP_m1_country1 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                  data=eu1_country1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MEP_m1_country2 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                  data=eu1_country2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MEP_m1_country3 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                  data=eu1_country3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MEP_m1_country4 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                  data=eu1_country4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MEP_m1_country5 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID  + polinterest + edu    + female + qage  , 
                                  data=eu1_country5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MEP_m1_country6 <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                  data=eu1_country6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 

mprobit_EP_m1_country1 <- mlogit::mlogit(q29d_powerEP ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu2_country1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_EP_m1_country2 <- mlogit::mlogit(q29d_powerEP ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu2_country2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_EP_m1_country3 <- mlogit::mlogit(q29d_powerEP ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu2_country3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_EP_m1_country4 <- mlogit::mlogit(q29d_powerEP ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu2_country4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_EP_m1_country5 <- mlogit::mlogit(q29d_powerEP ~ 1 | excl_natID  + polinterest + edu    + female + qage  , 
                                          data=eu2_country5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_EP_m1_country6 <- mlogit::mlogit(q29d_powerEP ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu2_country6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 

mprobit_MS_m1_country1 <- mlogit::mlogit(q29c_powerMS ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu3_country1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MS_m1_country2 <- mlogit::mlogit(q29c_powerMS ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu3_country2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MS_m1_country3 <- mlogit::mlogit(q29c_powerMS ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu3_country3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MS_m1_country4 <- mlogit::mlogit(q29c_powerMS ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu3_country4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MS_m1_country5 <- mlogit::mlogit(q29c_powerMS ~ 1 | excl_natID  + polinterest + edu    + female + qage  , 
                                          data=eu3_country5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 
mprobit_MS_m1_country6 <- mlogit::mlogit(q29c_powerMS ~ 1 | excl_natID  + polinterest + edu    + female + qage   + bornabroad , 
                                          data=eu3_country6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) 


eu_nospain <- eu[eu$qcountry!=2,]   
eu1_nospain <- mlogit.data(data=eu_nospain, shape="wide", choice="q20d_MEPdirect", reflevel="dk")
eu2_nospain <- mlogit.data(data=eu_nospain, shape="wide", choice="q29d_powerEP", reflevel="dk")
eu3_nospain <- mlogit.data(data=eu_nospain, shape="wide", choice="q29c_powerMS", reflevel="dk")



summary(mprobit_MEP_m1_nospain <- mlogit::mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest + edu    + female + qage   + bornabroad +  as.factor(country_id), 
                                         data=eu1_nospain, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_EP_m1_nospain <- mlogit::mlogit(q29d_powerEP ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                                        data=eu2_nospain, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_MS_m1_nospain <- mlogit(q29c_powerMS ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu3_nospain, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )




library(texreg) 

texreg(list(mprobit_MEP_m1, mprobit_EP_m1, mprobit_MS_m1),
       caption = "Multinomial Probit, EU Polarizing Knowledge - Main Model", 
       custom.model.names = c("EU - MEP", "EU - EP", "EU - MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_MEP_m2, mprobit_MEP_m4, mprobit_EP_m2, mprobit_EP_m4, mprobit_MS_m2,  mprobit_MS_m4),
       caption = "Multinomial Probit, EU Polarizing Knowledge - Partisanship Controls", 
       custom.model.names = c("MEP", "MEP", "EP", "EP","MS", "MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_MEP_m3, mprobit_MEP_m5, mprobit_EP_m3, mprobit_EP_m5, mprobit_MS_m3, mprobit_MS_m5),
       caption = "Multinomial Probit, EU Polarizing Knowledge - EU Attitude Controls", 
       custom.model.names = c("MEP", "MEP", "EP", "EP", "MS", "MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_MEP_m6, mprobit_MEP_m7, mprobit_EP_m6, mprobit_EP_m7, mprobit_MS_m6, mprobit_MS_m7),
       caption = "Multinomial Probit, EU Polarizing Knowledge - Confidence and CRT Controls", 
       custom.model.names = c("MEP", "MEP", "EP", "EP", "MS", "MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))


texreg(list(mprobit_MEP_m8, mprobit_MEP_m9, mprobit_MEP_m10, mprobit_EP_m8, mprobit_EP_m9, mprobit_EP_m10, mprobit_MS_m8, mprobit_MS_m9, mprobit_MS_m10),
       caption = "Multinomial Probit, EU Polarizing Knowledge - Knowledge Controls", 
       custom.model.names = c("MEP", "MEP", "MEP", "EP", "EP", "EP","MS", "MS", "MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))



texreg(list(mprobit_MEP_m11, mprobit_MEP_m12, mprobit_MEP_m13, mprobit_EP_m11, mprobit_EP_m12, mprobit_EP_m13, mprobit_MS_m11, mprobit_MS_m12, mprobit_MS_m13),
       caption = "Multinomial Probit, EU Polarizing Knowledge - Proxies for Exclusionary ID", 
       custom.model.names = c("MEP", "MEP", "MEP", "EP", "EP", "EP","MS", "MS", "MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

#by country 

texreg(list(mprobit_MEP_m1_country1, mprobit_MEP_m1_country2, mprobit_MEP_m1_country3, mprobit_MEP_m1_country4, mprobit_MEP_m1_country5, mprobit_MEP_m1_country6),
       caption = "Multinomial Probit, EU Polarizing Knowledge - MEP - By Country", 
       custom.model.names = c("Germany", "Spain", "France", "Italy", "Poland", "Sweden"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_EP_m1_country1, mprobit_EP_m1_country2, mprobit_EP_m1_country3, mprobit_EP_m1_country4, mprobit_EP_m1_country5, mprobit_EP_m1_country6),
       caption = "Multinomial Probit, EU Polarizing Knowledge - EP - By Country", 
       custom.model.names = c("Germany", "Spain", "France", "Italy", "Poland", "Sweden"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))


texreg(list(mprobit_MS_m1_country1, mprobit_MS_m1_country2, mprobit_MS_m1_country3, mprobit_MS_m1_country4, mprobit_MS_m1_country5, mprobit_MS_m1_country6),
       caption = "Multinomial Probit, EU Polarizing Knowledge - MS - By Country", 
       custom.model.names = c("Germany", "Spain", "France", "Italy", "Poland", "Sweden"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))


#Without Spain

texreg(list(mprobit_MEP_m1_nospain, mprobit_EP_m1_nospain, mprobit_MS_m1_nospain),
       caption = "Multinomial Probit, EU Polarizing Knowledge - Main Model", 
       custom.model.names = c("EU - MEP", "EU - EP", "EU - MS"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))


############################################
# Seconary Outcomes I: Non-EU knowledge
############################################


#main model


summary(mprobit_parl_m1 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu    + female + qage   + bornabroad +  as.factor(country_id), 
                                 data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m1 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_party_m1 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with political party family control

summary(mprobit_parl_m2 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu    + female + qage  + bornabroad +  as.factor(country_id)
                                 + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                 data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m2 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id)
                                + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian  + family_otherpart, 
                                data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) ) #removed no family category, to ensure convergence

summary(mprobit_party_m2 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id)
                                + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

#with pro-EU attitude control

summary(mprobit_parl_m3 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu  + pro_eu   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m3 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu   + pro_eu    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_party_m3 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu    + pro_eu   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with political ideology control

summary(mprobit_parl_m4 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu  + conservatism   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m4 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu   + conservatism    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_party_m4 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu    + conservatism   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with pro-EU index control 

summary(mprobit_parl_m5 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu  + proeu_attitudes   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m5 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu   + proeu_attitudes    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_party_m5 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu    + proeu_attitudes   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#with subjective knowledge

summary(mprobit_parl_m6 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu  + self_conf_pre   + female + qage  + bornabroad +  as.factor(country_id), 
                                  data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m6 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu   + self_conf_pre    +  female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_party_m6 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu    + self_conf_pre   + female + qage  + bornabroad + as.factor(country_id), 
                                   data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with CRT

summary(mprobit_parl_m7 <- mlogit(q20h_parl ~ 1 | excl_natID + polinterest + edu  + crt_sum   + female + qage  + bornabroad +  as.factor(country_id), 
                                  data=eu_n1, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_gov_m7 <- mlogit(q20i_headgov ~ 1 |  excl_natID + polinterest +  edu   + crt_sum    +  female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu_n2, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_party_m7 <- mlogit(q20j_largestparty ~ 1 |  excl_natID + polinterest + edu    + crt_sum   + female + qage  + bornabroad + as.factor(country_id), 
                                   data=eu_n3, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )




texreg(list(mprobit_parl_m1, mprobit_gov_m1, mprobit_party_m1),
       caption = "Multinomial Probit, Non-EU Knowledge - Main Model", 
       custom.model.names = c("Parliament", "Government", "Party"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_parl_m2, mprobit_parl_m4, mprobit_gov_m2, mprobit_gov_m4, mprobit_party_m2, mprobit_party_m4),
       caption = "Multinomial Probit, Non-EU Knowledge - Partisanship Controls", 
       custom.model.names = c("Parliament", "Parliament","Government","Government", "Party" ,"Party"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_parl_m3, mprobit_parl_m5, mprobit_gov_m3, mprobit_gov_m5, mprobit_party_m3, mprobit_party_m5),
       caption = "Multinomial Probit, Non-EU Knowledge - EU Attitude Controls", 
       custom.model.names = c("Parliament", "Parliament", "Government", "Government","Party" ,"Party"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))


texreg(list(mprobit_parl_m6, mprobit_parl_m7, mprobit_gov_m6, mprobit_gov_m7, mprobit_party_m6, mprobit_party_m7),
       caption = "Multinomial Probit, Non-EU Knowledge - Confidence and CRT Controls", 
       custom.model.names = c("Parliament", "Parliament", "Government", "Government","Party" ,"Party"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))




############################################
# Secondary Outcomes II: Non-Polarizing EU Knowledge
############################################


#main model

summary(mprobit_juncker_m1 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu    + female + qage   + bornabroad +  as.factor(country_id), 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m1 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m1 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with political party family control

summary(mprobit_juncker_m2 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu    + female + qage  + bornabroad +  as.factor(country_id)
                                 + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem   , 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m2 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu      +  female + qage  + bornabroad +  as.factor(country_id)
                                + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m2 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu      + female + qage  + bornabroad + as.factor(country_id)
                                + family_conserv + family_socialist + family_green + family_radtan + family_lib + family_radleft + family_chrisdem  + family_regional  + family_m5s + family_agrarian + family_nofam + family_otherpart, 
                                data=eu6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

#with pro-EU attitude control

summary(mprobit_juncker_m3 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu  + pro_eu   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m3 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu   + pro_eu    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m3 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu    + pro_eu   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with political ideology control

summary(mprobit_juncker_m4 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu  + conservatism   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m4 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu   + conservatism    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m4 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu    + conservatism   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )


#with pro-EU index control 

table(eu$proeu_attitudes)

summary(mprobit_juncker_m5 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu  + proeu_attitudes   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m5 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu   + proeu_attitudes    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m5 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu    + proeu_attitudes   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#with subjective knowledge control

summary(mprobit_juncker_m6 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu  + self_conf_pre   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m6 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu   + self_conf_pre    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m6 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu    + self_conf_pre   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu6, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )



#with CRT control 

summary(mprobit_juncker_m7 <- mlogit(q20c_juncker ~ 1 | excl_natID + polinterest + edu  + crt_sum   + female + qage  + bornabroad +  as.factor(country_id), 
                                 data=eu4, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE))

summary(mprobit_epterm_m7 <- mlogit(q20e_term ~ 1 |  excl_natID + polinterest +  edu   + crt_sum    +  female + qage  + bornabroad +  as.factor(country_id), 
                                data=eu5, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE) )

summary(mprobit_epelection_m7 <- mlogit(q20g_epelection ~ 1 |  excl_natID + polinterest + edu    + crt_sum   + female + qage  + bornabroad + as.factor(country_id), 
                                data=eu6, reflevel="dk", alt.subset=c("dk"0
                                                                      lk         , "correct" ,"incorrect"), probit=TRUE) )



texreg(list(mprobit_juncker_m1, mprobit_epterm_m1, mprobit_epelection_m1),
       caption = "Multinomial Probit, EU Non-Polarizing Knowledge - Main Model", 
       custom.model.names = c("Juncker", "EP Term", "EP Election"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_juncker_m2, mprobit_juncker_m4, mprobit_epterm_m2, mprobit_epterm_m4, mprobit_epelection_m2,  mprobit_epelection_m4),
       caption = "Multinomial Probit, EU Non-Polarizing Knowledge - Partisanship Controls", 
       custom.model.names = c("Juncker", "Juncker", "EP Term", "EP Term", "EP Election" , "EP Election"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_juncker_m3, mprobit_juncker_m5, mprobit_epterm_m3, mprobit_epterm_m5, mprobit_epelection_m3, mprobit_epelection_m5),
       caption = "Multinomial Probit, EU Non-Polarizing Knowledge - EU Attitude Controls", 
       custom.model.names = c("Juncker", "Juncker","EP Term", "EP Term", "EP Election", "EP Election"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))

texreg(list(mprobit_juncker_m6, mprobit_juncker_m7, mprobit_epterm_m6, mprobit_epterm_m7, mprobit_epelection_m6, mprobit_epelection_m1),
       caption = "Multinomial Probit, EU Non-Polarizing Knowledge - Confidence and CRT Controls", 
       custom.model.names = c("Juncker", "Juncker", "EP Term",  "EP Term","EP Election", "EP Election"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))




# for main paper

texreg(list(mprobit_juncker_m1, mprobit_epterm_m1, mprobit_epelection_m1, mprobit_parl_m1, mprobit_gov_m1, mprobit_party_m1),
       caption = "Multinomial Probit, Non-Polarizing Knowledge - EU and non-EU Beliefs", 
       custom.model.names = c("Juncker", "EP Term", "EP Election", "Parliament", "Government", "Party"),
       caption.above = TRUE, digits = 3, stars = c(0.001, 0.01, 0.05))




#####plots


# bootstrapping to get confidence intervals of predicted probabilities

B <- 400 #number of times we run the draws

edu <- mean(eu$edu, na.rm=TRUE)
polinterest <- mean(eu$polinterest, na.rm=TRUE)
age <- mean(eu$qage, na.rm=TRUE)
female <- 0 
bornabroad <- 0 
id1 <- 1
id0 <- 0

pr.dk.eff1 <- matrix(NA,B,1)
pr.correct.eff1 <- matrix(NA,B,1)
pr.incorrect.eff1 <-matrix(NA,B,1)  


for(b in 1:B){ 
  resample <- sample(eu$country_id, 6, replace=T) 
  resample_cntry2 <- eu[eu$country_id==resample[1],]
  resample_cntry3 <- eu[eu$country_id==resample[2],]
  resample_cntry4 <- eu[eu$country_id==resample[3],]
  resample_cntry5 <- eu[eu$country_id==resample[4],]
  resample_cntry6 <- eu[eu$country_id==resample[5],]
  resample_cntry7 <- eu[eu$country_id==resample[6],]
  merged_resample <- rbind(resample_cntry2, resample_cntry3, resample_cntry4, resample_cntry5, resample_cntry6, resample_cntry7)
  eu1_boot <- mlogit.data(data=merged_resample, shape="wide", choice="q20d_MEPdirect", reflevel="dk")
  mprobit1 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest +  edu  +  female + qage  + bornabroad +  as.factor(country_id), 
                     data=eu1_boot, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE)
  pr.dk1 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct1 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect1 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk0 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct0 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect0 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk.eff1[b,] <- pr.dk1 - pr.dk0
  pr.correct.eff1[b,] <- pr.correct1 - pr.correct0
  pr.incorrect.eff1[b,] <- pr.incorrect1 - pr.incorrect0    
  drop(resample_cntry2)
  drop(resample_cntry3)
  drop(resample_cntry4)
  drop(resample_cntry5)
  drop(resample_cntry6)
  drop(resample_cntry7)
  drop(merged_resample)
  drop(eu1_boot)
}

correct.outcome.mep <- c(mean(pr.correct.eff1),  quantile(pr.correct.eff1, c(0.025, 0.975))) 
incorrect.outcome.mep <- c(mean(pr.incorrect.eff1), quantile(pr.incorrect.eff1, c(0.025, 0.975))) 
dk.outcome.mep <- c(mean(pr.dk.eff1), quantile(pr.dk.eff1, c(0.025, 0.975))) 

correct.outcome.mep2 <- c(mean(pr.correct.eff1),  mean(pr.correct.eff1)-1.96*sd(pr.correct.eff1), mean(pr.correct.eff1)+1.96*sd(pr.correct.eff1))
incorrect.outcome.mep2 <- c(mean(pr.incorrect.eff1), mean(pr.incorrect.eff1)-1.96*sd(pr.incorrect.eff1), mean(pr.incorrect.eff1)+1.96*sd(pr.incorrect.eff1))
dk.outcome.mep2 <- c(mean(pr.dk.eff1), mean(pr.dk.eff1)-1.96*sd(pr.dk.eff1), mean(pr.dk.eff1)+1.96*sd(pr.dk.eff1))


edu <- mean(eu$edu, na.rm=TRUE)
polinterest <- mean(eu$polinterest, na.rm=TRUE)
age <- mean(eu$qage, na.rm=TRUE)
female <- 0 
bornabroad <- 0 
id1 <- 1
id0 <- 0

pr.dk.eff2 <- matrix(NA,B,1)
pr.correct.eff2 <- matrix(NA,B,1)
pr.incorrect.eff2 <-matrix(NA,B,1)  


for(b in 1:B){ 
  resample <- sample(eu$country_id, 6,replace=T) 
  resample_cntry2 <- eu[eu$country_id==resample[1],]
  resample_cntry3 <- eu[eu$country_id==resample[2],]
  resample_cntry4 <- eu[eu$country_id==resample[3],]
  resample_cntry5 <- eu[eu$country_id==resample[4],]
  resample_cntry6 <- eu[eu$country_id==resample[5],]
  resample_cntry7 <- eu[eu$country_id==resample[6],]
  merged_resample <- rbind(resample_cntry2, resample_cntry3, resample_cntry4, resample_cntry5, resample_cntry6, resample_cntry7)
  eu2_boot <- mlogit.data(data=merged_resample, shape="wide", choice="q29d_powerEP", reflevel="dk")
  mprobit1 <- mlogit(q29d_powerEP ~ 1 | excl_natID + polinterest +  edu  +  female + qage  + bornabroad +  as.factor(country_id), 
                     data=eu2_boot, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE)
  pr.dk1 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct1 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect1 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk0 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct0 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect0 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk.eff2[b,] <- pr.dk1 - pr.dk0
  pr.correct.eff2[b,] <- pr.correct1 - pr.correct0
  pr.incorrect.eff2[b,] <- pr.incorrect1 - pr.incorrect0    
  drop(resample_cntry2)
  drop(resample_cntry3)
  drop(resample_cntry4)
  drop(resample_cntry5)
  drop(resample_cntry6)
  drop(resample_cntry7)
  drop(merged_resample)
  drop(eu2_boot)
}


correct.outcome.ep <- c(mean(pr.correct.eff2),  quantile(pr.correct.eff2, c(0.025, 0.975))) 
incorrect.outcome.ep <- c(mean(pr.incorrect.eff2), quantile(pr.incorrect.eff2, c(0.025, 0.975))) 
dk.outcome.ep <- c(mean(pr.dk.eff2), quantile(pr.dk.eff2, c(0.025, 0.975))) 

correct.outcome.ep2 <- c(mean(pr.correct.eff2),  mean(pr.correct.eff2)-1.96*sd(pr.correct.eff2), mean(pr.correct.eff2)+1.96*sd(pr.correct.eff2))
incorrect.outcome.ep2 <- c(mean(pr.incorrect.eff2), mean(pr.incorrect.eff2)-1.96*sd(pr.incorrect.eff2), mean(pr.incorrect.eff2)+1.96*sd(pr.incorrect.eff2))
dk.outcome.ep2 <- c(mean(pr.dk.eff2), mean(pr.dk.eff2)-1.96*sd(pr.dk.eff2), mean(pr.dk.eff2)+1.96*sd(pr.dk.eff2))


edu <- mean(eu$edu, na.rm=TRUE)
polinterest <- mean(eu$polinterest, na.rm=TRUE)
age <- mean(eu$qage, na.rm=TRUE)
female <- 0 
bornabroad <- 0 
id1 <- 1
id0 <- 0

pr.dk.eff3 <- matrix(NA,B,1)
pr.correct.eff3 <- matrix(NA,B,1)
pr.incorrect.eff3 <-matrix(NA,B,1)  


for(b in 1:B){ 
  resample <- sample(eu$country_id, 6,replace=T) 
  resample_cntry2 <- eu[eu$country_id==resample[1],]
  resample_cntry3 <- eu[eu$country_id==resample[2],]
  resample_cntry4 <- eu[eu$country_id==resample[3],]
  resample_cntry5 <- eu[eu$country_id==resample[4],]
  resample_cntry6 <- eu[eu$country_id==resample[5],]
  resample_cntry7 <- eu[eu$country_id==resample[6],]
  merged_resample <- rbind(resample_cntry2, resample_cntry3, resample_cntry4, resample_cntry5, resample_cntry6, resample_cntry7)
  eu3_boot <- mlogit.data(data=merged_resample, shape="wide", choice="q29c_powerMS", reflevel="dk")
  mprobit1 <- mlogit(q29c_powerMS ~ 1 | excl_natID + polinterest +  edu  +  female + qage  + bornabroad +  as.factor(country_id), 
                     data=eu3_boot, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE)
  pr.dk1 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct1 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect1 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id1 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id1 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk0 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct0 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect0 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*id0 + mprobit1$coef[5]*polinterest + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*id0 + mprobit1$coef[6]*polinterest + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk.eff3[b,] <- pr.dk1 - pr.dk0
  pr.correct.eff3[b,] <- pr.correct1 - pr.correct0
  pr.incorrect.eff3[b,] <- pr.incorrect1 - pr.incorrect0    
  drop(resample_cntry2)
  drop(resample_cntry3)
  drop(resample_cntry4)
  drop(resample_cntry5)
  drop(resample_cntry6)
  drop(resample_cntry7)
  drop(merged_resample)
  drop(eu3_boot)
}

correct.outcome.ms <- c(mean(pr.correct.eff3),  quantile(pr.correct.eff3, c(0.025, 0.975))) 
incorrect.outcome.ms <- c(mean(pr.incorrect.eff3), quantile(pr.incorrect.eff3, c(0.025, 0.975))) 
dk.outcome.ms <- c(mean(pr.dk.eff3), quantile(pr.dk.eff3, c(0.025, 0.975))) 

correct.outcome.ms2 <- c(mean(pr.correct.eff3),  mean(pr.correct.eff3)-1.96*sd(pr.correct.eff3), mean(pr.correct.eff3)+1.96*sd(pr.correct.eff3))
incorrect.outcome.ms2 <- c(mean(pr.incorrect.eff3), mean(pr.incorrect.eff3)-1.96*sd(pr.incorrect.eff3), mean(pr.incorrect.eff3)+1.96*sd(pr.incorrect.eff3))
dk.outcome.ms2 <- c(mean(pr.dk.eff3), mean(pr.dk.eff3)-1.96*sd(pr.dk.eff3), mean(pr.dk.eff3)+1.96*sd(pr.dk.eff3))


#pol interest

B <- 400 #number of times we run the draws

edu <- mean(eu$edu, na.rm=TRUE)
polinterest1 <- mean(eu$polinterest, na.rm=TRUE) + 2*sd(eu$polinterest, na.rm=TRUE)
polinterest0 <- mean(eu$polinterest, na.rm=TRUE) - 2*sd(eu$polinterest, na.rm=TRUE)
age <- mean(eu$qage, na.rm=TRUE)
female <- 0 
bornabroad <- 0 
euid <- 0

pr.dk.eff1 <- matrix(NA,B,1)
pr.correct.eff1 <- matrix(NA,B,1)
pr.incorrect.eff1 <-matrix(NA,B,1)  


for(b in 1:B){ 
  resample <- sample(eu$country_id, 6,replace=T) 
  resample_cntry2 <- eu[eu$country_id==resample[1],]
  resample_cntry3 <- eu[eu$country_id==resample[2],]
  resample_cntry4 <- eu[eu$country_id==resample[3],]
  resample_cntry5 <- eu[eu$country_id==resample[4],]
  resample_cntry6 <- eu[eu$country_id==resample[5],]
  resample_cntry7 <- eu[eu$country_id==resample[6],]
  merged_resample <- rbind(resample_cntry2, resample_cntry3, resample_cntry4, resample_cntry5, resample_cntry6, resample_cntry7)
  eu1_boot <- mlogit.data(data=merged_resample, shape="wide", choice="q20d_MEPdirect", reflevel="dk")
  mprobit1 <- mlogit(q20d_MEPdirect ~ 1 | excl_natID + polinterest +  edu  +  female + qage  + bornabroad +  as.factor(country_id), 
                     data=eu1_boot, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE)
  pr.dk1 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct1 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect1 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk0 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct0 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect0 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk.eff1[b,] <- pr.dk1 - pr.dk0
  pr.correct.eff1[b,] <- pr.correct1 - pr.correct0
  pr.incorrect.eff1[b,] <- pr.incorrect1 - pr.incorrect0    
  drop(resample_cntry2)
  drop(resample_cntry3)
  drop(resample_cntry4)
  drop(resample_cntry5)
  drop(resample_cntry6)
  drop(resample_cntry7)
  drop(merged_resample)
  drop(eu1_boot)
}


correct.outcome2.mep <- c(mean(pr.correct.eff1),  quantile(pr.correct.eff1, c(0.025, 0.975))) 
incorrect.outcome2.mep <- c(mean(pr.incorrect.eff1), quantile(pr.incorrect.eff1, c(0.025, 0.975))) 
dk.outcome2.mep <- c(mean(pr.dk.eff1), quantile(pr.dk.eff1, c(0.025, 0.975))) 

correct.outcome2.mep2 <- c(mean(pr.correct.eff1),  mean(pr.correct.eff1)-1.96*sd(pr.correct.eff1), mean(pr.correct.eff1)+1.96*sd(pr.correct.eff1))
incorrect.outcome2.mep2 <- c(mean(pr.incorrect.eff1), mean(pr.incorrect.eff1)-1.96*sd(pr.incorrect.eff1), mean(pr.incorrect.eff1)+1.96*sd(pr.incorrect.eff1))
dk.outcome2.mep2 <- c(mean(pr.dk.eff1), mean(pr.dk.eff1)-1.96*sd(pr.dk.eff1), mean(pr.dk.eff1)+1.96*sd(pr.dk.eff1))

pr.dk.eff2 <- matrix(NA,B,1)
pr.correct.eff2 <- matrix(NA,B,1)
pr.incorrect.eff2 <-matrix(NA,B,1)  


for(b in 1:B){ 
  resample <- sample(eu$country_id, 6,replace=T) 
  resample_cntry2 <- eu[eu$country_id==resample[1],]
  resample_cntry3 <- eu[eu$country_id==resample[2],]
  resample_cntry4 <- eu[eu$country_id==resample[3],]
  resample_cntry5 <- eu[eu$country_id==resample[4],]
  resample_cntry6 <- eu[eu$country_id==resample[5],]
  resample_cntry7 <- eu[eu$country_id==resample[6],]
  merged_resample <- rbind(resample_cntry2, resample_cntry3, resample_cntry4, resample_cntry5, resample_cntry6, resample_cntry7)
  eu2_boot <- mlogit.data(data=merged_resample, shape="wide", choice="q29d_powerEP", reflevel="dk")
  mprobit1 <- mlogit(q29d_powerEP ~ 1 | excl_natID + polinterest +  edu  +  female + qage  + bornabroad +  as.factor(country_id), 
                     data=eu2_boot, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE)
  pr.dk1 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct1 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect1 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk0 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct0 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect0 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk.eff2[b,] <- pr.dk1 - pr.dk0
  pr.correct.eff2[b,] <- pr.correct1 - pr.correct0
  pr.incorrect.eff2[b,] <- pr.incorrect1 - pr.incorrect0    
  drop(resample_cntry2)
  drop(resample_cntry3)
  drop(resample_cntry4)
  drop(resample_cntry5)
  drop(resample_cntry6)
  drop(resample_cntry7)
  drop(merged_resample)
  drop(eu2_boot)
}

correct.outcome2.ep <- c(mean(pr.correct.eff2),  quantile(pr.correct.eff2, c(0.025, 0.975))) 
incorrect.outcome2.ep <- c(mean(pr.incorrect.eff2), quantile(pr.incorrect.eff2, c(0.025, 0.975))) 
dk.outcome2.ep <- c(mean(pr.dk.eff2), quantile(pr.dk.eff2, c(0.025, 0.975))) 

correct.outcome2.ep2 <- c(mean(pr.correct.eff2),  mean(pr.correct.eff2)-1.96*sd(pr.correct.eff2), mean(pr.correct.eff2)+1.96*sd(pr.correct.eff2))
incorrect.outcome2.ep2 <- c(mean(pr.incorrect.eff2), mean(pr.incorrect.eff2)-1.96*sd(pr.incorrect.eff2), mean(pr.incorrect.eff2)+1.96*sd(pr.incorrect.eff2))
dk.outcome2.ep2 <- c(mean(pr.dk.eff2), mean(pr.dk.eff2)-1.96*sd(pr.dk.eff2), mean(pr.dk.eff2)+1.96*sd(pr.dk.eff2))

pr.dk.eff3 <- matrix(NA,B,1)
pr.correct.eff3 <- matrix(NA,B,1)
pr.incorrect.eff3 <-matrix(NA,B,1)  


for(b in 1:B){ 
  resample <- sample(eu$country_id, 6,replace=T) 
  resample_cntry2 <- eu[eu$country_id==resample[1],]
  resample_cntry3 <- eu[eu$country_id==resample[2],]
  resample_cntry4 <- eu[eu$country_id==resample[3],]
  resample_cntry5 <- eu[eu$country_id==resample[4],]
  resample_cntry6 <- eu[eu$country_id==resample[5],]
  resample_cntry7 <- eu[eu$country_id==resample[6],]
  merged_resample <- rbind(resample_cntry2, resample_cntry3, resample_cntry4, resample_cntry5, resample_cntry6, resample_cntry7)
  eu3_boot <- mlogit.data(data=merged_resample, shape="wide", choice="q29c_powerMS", reflevel="dk")
  mprobit1 <- mlogit(q29c_powerMS ~ 1 | excl_natID + polinterest +  edu  +  female + qage  + bornabroad +  as.factor(country_id), 
                     data=eu3_boot, reflevel="dk", alt.subset=c("dk", "correct" ,"incorrect"), probit=TRUE)
  pr.dk1 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct1 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect1 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest1 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest1 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk0 <-1/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.correct0 <- exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad )/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.incorrect0 <- exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad)/(1 + exp(mprobit1$coef[1]*1 + mprobit1$coef[3]*euid + mprobit1$coef[5]*polinterest0 + mprobit1$coef[7]*edu + mprobit1$coef[9]*female + mprobit1$coef[11]*age + mprobit1$coef[13]*bornabroad) + exp(mprobit1$coef[2]*1 + mprobit1$coef[4]*euid + mprobit1$coef[6]*polinterest0 + mprobit1$coef[8]*edu + mprobit1$coef[10]*female + mprobit1$coef[12]*age + mprobit1$coef[14]*bornabroad  ))
  pr.dk.eff3[b,] <- pr.dk1 - pr.dk0
  pr.correct.eff3[b,] <- pr.correct1 - pr.correct0
  pr.incorrect.eff3[b,] <- pr.incorrect1 - pr.incorrect0    
  drop(resample_cntry2)
  drop(resample_cntry3)
  drop(resample_cntry4)
  drop(resample_cntry5)
  drop(resample_cntry6)
  drop(resample_cntry7)
  drop(merged_resample)
  drop(eu3_boot)
}


correct.outcome2.ms <- c(mean(pr.correct.eff3),  quantile(pr.correct.eff3, c(0.025, 0.975))) 
incorrect.outcome2.ms <- c(mean(pr.incorrect.eff3), quantile(pr.incorrect.eff3, c(0.025, 0.975))) 
dk.outcome2.ms <- c(mean(pr.dk.eff3), quantile(pr.dk.eff3, c(0.025, 0.975))) 

correct.outcome2.ms2 <- c(mean(pr.correct.eff3),  mean(pr.correct.eff3)-1.96*sd(pr.correct.eff3), mean(pr.correct.eff3)+1.96*sd(pr.correct.eff3))
incorrect.outcome2.ms2 <- c(mean(pr.incorrect.eff3), mean(pr.incorrect.eff3)-1.96*sd(pr.incorrect.eff3), mean(pr.incorrect.eff3)+1.96*sd(pr.incorrect.eff3))
dk.outcome2.ms2 <- c(mean(pr.dk.eff3), mean(pr.dk.eff3)-1.96*sd(pr.dk.eff3), mean(pr.dk.eff3)+1.96*sd(pr.dk.eff3))


###figures

#exclusionary id

modeleu_plot1 = rbind(correct.outcome.mep2, incorrect.outcome.mep2, dk.outcome.mep2,
                    correct.outcome.ep2, incorrect.outcome.ep2, dk.outcome.ep2,
                    correct.outcome.ms2, incorrect.outcome.ms2, dk.outcome.ms2)

modeleu_plot1 = modeleu_plot1*100

mod <- c(1, 1, 1, 3, 3, 3, 5, 5, 5)
out <- c(1, 2, 3, 1, 2, 3, 1, 2, 3)

modeleu_plot1 <- cbind(modeleu_plot1, mod, out)
colnames(modeleu_plot1) = c("effect","CI.lower","CI.upper","mod","out")
modeleu_plot1 = as.data.frame(modeleu_plot1)
modeleu_plot1$model[modeleu_plot1$mod==1] = "MEP"
modeleu_plot1$model[modeleu_plot1$mod==3] = "EP"
modeleu_plot1$model[modeleu_plot1$mod==5] = "MS"


modeleu_plot1$model <- factor(modeleu_plot1$model, levels= c("MS", "EP", "MEP"), ordered=TRUE)

print(levels(modeleu_plot1$model))

modeleu_plot1$outcomes[modeleu_plot1$out==1] = "Correct"
modeleu_plot1$outcomes[modeleu_plot1$out==2] = "Incorrect"
modeleu_plot1$outcomes[modeleu_plot1$out==3] = "DK"

modeleu_plot1$outcomes <- factor(modeleu_plot1$outcomes, levels= c("Correct", "Incorrect", "DK"), ordered=TRUE)

print(levels(modeleu_plot1$outcomes))


zp1 <- ggplot(modeleu_plot1) 
zp1 <- zp1 + geom_hline(yintercept = 0, colour = gray(1/2), lty = 2)
zp1 <- zp1 + geom_pointrange(aes(x = model, y = effect, ymin = CI.lower ,colour = outcomes, shape=outcomes,
                                 ymax = CI.upper), lwd = 1, position = position_dodge(width = 1/2))
zp1 <- zp1 + coord_flip() + theme_bw()
zp1 = zp1 + 
  theme(axis.title = element_blank()) +
  theme(plot.title = element_text(hjust = 0.5, face="bold")) + 
  theme(axis.text.y = element_text(size = rel(1.5), colour="black", face="bold")) +
  theme(axis.text.x = element_text(size = rel(1.3), colour="black")) +
  theme(legend.position="bottom") +
  theme(legend.title=element_blank()) +
  theme(legend.text = element_text(size = rel(5/4),vjust = 1)) + 
  scale_colour_manual(values=c("gray", "gray44", "gray10"))+
  scale_y_continuous(breaks=c(-10, -5,  0, 5, 10), limits=c(-8, 8)) 

zp1


ggsave("mnp_combined_exclusionaryID_grey.png",
       zp1,
       width = 8,
       height = 6,
       dpi = 1200)


#pol interest

modelpolinterest_plot1 = rbind(correct.outcome2.mep2, incorrect.outcome2.mep2, dk.outcome2.mep2,
                      correct.outcome2.ep2, incorrect.outcome2.ep2, dk.outcome2.ep2,
                      correct.outcome2.ms2, incorrect.outcome2.ms2, dk.outcome2.ms2)

modelpolinterest_plot1 = modelpolinterest_plot1*100

mod <- c(1, 1, 1, 3, 3, 3, 5, 5, 5)
out <- c(1, 2, 3, 1, 2, 3, 1, 2, 3)

modelpolinterest_plot1 <- cbind(modelpolinterest_plot1, mod, out)
colnames(modelpolinterest_plot1) = c("effect","CI.lower","CI.upper","mod","out")
modelpolinterest_plot1 = as.data.frame(modelpolinterest_plot1)
modelpolinterest_plot1$model[modelpolinterest_plot1$mod==1] = "MEP"
modelpolinterest_plot1$model[modelpolinterest_plot1$mod==3] = "EP"
modelpolinterest_plot1$model[modelpolinterest_plot1$mod==5] = "MS"


modelpolinterest_plot1$model <- factor(modelpolinterest_plot1$model, levels= c("MS", "EP", "MEP"), ordered=TRUE)
print(levels(modelpolinterest_plot1$model))


modelpolinterest_plot1$outcomes[modelpolinterest_plot1$out==1] = "Correct"
modelpolinterest_plot1$outcomes[modelpolinterest_plot1$out==2] = "Incorrect"
modelpolinterest_plot1$outcomes[modelpolinterest_plot1$out==3] = "DK"

modelpolinterest_plot1$outcomes <- factor(modelpolinterest_plot1$outcomes, levels= c("Correct", "Incorrect", "DK"), ordered=TRUE)

print(levels(modelpolinterest_plot1$outcomes))


# Plot


zp2 <- ggplot(modelpolinterest_plot1) 
zp2 <- zp2 + geom_hline(yintercept = 0, colour = gray(1/2), lty = 2)
zp2 <- zp2 + geom_pointrange(aes(x = model, y = effect, ymin = CI.lower ,colour = outcomes, shape=outcomes,
                                 ymax = CI.upper), lwd = 1, position = position_dodge(width = 1/2))
zp2 <- zp2 + coord_flip() + theme_bw()
zp2 = zp2 + 
  theme(axis.title = element_blank()) +
  theme(plot.title = element_text(hjust = 0.5, face="bold")) + 
 theme(axis.text.y = element_text(size = rel(1.5), colour="black", face="bold")) +
  theme(axis.text.x = element_text(size = rel(1.3), colour="black")) +
  theme(legend.position="bottom") +
  theme(legend.title=element_blank()) +
  theme(legend.text = element_text(size = rel(5/4),vjust = 1)) + 
  scale_colour_manual(values=c("gray", "gray44", "gray10"))+
  scale_y_continuous(breaks=c(-30, -20, -10,  0, 10, 20, 30), limits=c(-30, 30)) 

zp2

ggsave("mnp_combined_polinterest_grey.png",
       zp2,
       width = 8,
       height = 6,
       dpi = 1200)



